@@ -62,7 +62,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:339  */
+#line 1 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:339  */
 
 
 /***************************************************************************
@@ -169,6 +169,11 @@ DFARS 252.227-7013 or 48 CFR 52.227-19, as applicable.
 #include <ctype.h>
 #include "vcc.h"
 
+#ifdef _WIN32
+#define strncasecmp _strnicmp
+#define strcasecmp _stricmp
+#endif
+
 /* The following is a hack that I hope will get things compiling
  * on SunOS 4.1.x systems
  */
@@ -239,7 +244,7 @@ static void appendValue(const char *value);
 static void mime_error_(const char *s);
 
 
-#line 243 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:339  */
+#line 248 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -259,8 +264,8 @@ static void mime_error_(const char *s);
 
 /* In a future release of Bison, this section will be replaced
    by #include "vcc-parser.h".  */
-#ifndef YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_08_3_1_X86_64_BUILD_SRC_VCC_PARSER_H_INCLUDED
-# define YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_08_3_1_X86_64_BUILD_SRC_VCC_PARSER_H_INCLUDED
+#ifndef YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_12_3_1_I686_BUILD_SRC_VCC_PARSER_H_INCLUDED
+# define YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_12_3_1_I686_BUILD_SRC_VCC_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -300,13 +305,13 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 182 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:355  */
+#line 187 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:355  */
 
     char *str;
     VObject *vobj;
     
 
-#line 310 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:355  */
+#line 315 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -319,11 +324,11 @@ extern YYSTYPE yylval;
 
 int yyparse (void);
 
-#endif /* !YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_08_3_1_X86_64_BUILD_SRC_VCC_PARSER_H_INCLUDED  */
+#endif /* !YY_YY_USR_SRC_PORTS_KF5_KCALCORE_KF5_KCALCORE_17_12_3_1_I686_BUILD_SRC_VCC_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 327 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:358  */
+#line 332 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -622,11 +627,11 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   210,   210,   214,   213,   216,   220,   221,   226,   225,
-     236,   235,   247,   248,   252,   251,   261,   265,   264,   269,
-     275,   276,   279,   282,   286,   293,   296,   296,   297,   301,
-     303,   308,   307,   313,   312,   318,   319,   323,   324,   325,
-     330,   329,   341,   340,   354,   353,   365,   364
+       0,   215,   215,   219,   218,   221,   225,   226,   231,   230,
+     241,   240,   252,   253,   257,   256,   266,   270,   269,   274,
+     280,   281,   284,   287,   291,   298,   301,   301,   302,   306,
+     308,   313,   312,   318,   317,   323,   324,   328,   329,   330,
+     335,   334,   346,   345,   359,   358,   370,   369
 };
 #endif
 
@@ -1442,220 +1447,220 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 214 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 219 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { addList(&vObjList, (yyvsp[0].vobj)); curObj = 0; }
-#line 1448 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1453 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 217 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 222 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { addList(&vObjList, (yyvsp[0].vobj)); curObj = 0; }
-#line 1454 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1459 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 226 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 231 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VCARD);
         if (!pushVObject(VCCardProp)) YYERROR;
         }
-#line 1463 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1468 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 231 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 236 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         (yyval.vobj) = popVObject();
         }
-#line 1472 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1477 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 236 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 241 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VCARD);
         if (!pushVObject(VCCardProp)) YYERROR;
         }
-#line 1481 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1486 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 241 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 246 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         (yyval.vobj) = popVObject();
         }
-#line 1490 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1495 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 252 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 257 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VALUES);
         }
-#line 1498 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1503 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 256 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 261 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         if (lexWithinMode(L_BASE64) || lexWithinMode(L_QUOTED_PRINTABLE))
            lexPopMode(0);
         lexPopMode(0);
         }
-#line 1508 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1513 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 265 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 270 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         enterProps((yyvsp[0].str));
         }
-#line 1516 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1521 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 270 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 275 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         enterProps((yyvsp[0].str));
         }
-#line 1524 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1529 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 283 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 288 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         enterAttr((yyvsp[0].str),0);
         }
-#line 1532 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1537 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 287 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 292 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         enterAttr((yyvsp[-2].str),(yyvsp[0].str));
 
         }
-#line 1541 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1546 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 296 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 301 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { appendValue((yyvsp[-1].str)); }
-#line 1547 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1552 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 298 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 303 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { appendValue((yyvsp[0].str)); }
-#line 1553 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1558 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 303 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 308 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { (yyval.str) = 0; }
-#line 1559 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1564 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 308 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 313 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { if (!pushVObject(VCCalProp)) YYERROR; }
-#line 1565 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1570 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 311 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 316 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { (yyval.vobj) = popVObject(); }
-#line 1571 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1576 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 313 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 318 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { if (!pushVObject(VCCalProp)) YYERROR; }
-#line 1577 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1582 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 315 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 320 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     { (yyval.vobj) = popVObject(); }
-#line 1583 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1588 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 330 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 335 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VEVENT);
         if (!pushVObject(VCEventProp)) YYERROR;
         }
-#line 1592 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1597 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 336 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 341 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         popVObject();
         }
-#line 1601 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1606 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 341 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 346 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VEVENT);
         if (!pushVObject(VCEventProp)) YYERROR;
         }
-#line 1610 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1615 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 346 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 351 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         popVObject();
         }
-#line 1619 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1624 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 354 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 359 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VTODO);
         if (!pushVObject(VCTodoProp)) YYERROR;
         }
-#line 1628 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1633 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 360 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 365 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         popVObject();
         }
-#line 1637 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1642 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 365 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 370 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPushMode(L_VTODO);
         if (!pushVObject(VCTodoProp)) YYERROR;
         }
-#line 1646 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1651 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 370 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1646  */
+#line 375 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1646  */
     {
         lexPopMode(0);
         popVObject();
         }
-#line 1655 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1660 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
     break;
 
 
-#line 1659 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/build/src/vcc-parser.c" /* yacc.c:1646  */
+#line 1664 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/build/src/vcc-parser.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1883,7 +1888,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 376 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.08.3-1.x86_64/src/kcalcore-17.08.3/src/versit/vcc.y" /* yacc.c:1906  */
+#line 381 "/usr/src/ports/kf5-kcalcore/kf5-kcalcore-17.12.3-1.i686/src/kcalcore-17.12.3/src/versit/vcc.y" /* yacc.c:1906  */
 
 /****************************************************************************/
 static int pushVObject(const char *prop)
